#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   persistent-sqlite
version:                2.13.2.0
visibility:             public
id:                     persistent-sqlite-2.13.2.0-4aMdRx7tYJFJ1ueOkv8VbW
key:                    persistent-sqlite-2.13.2.0-4aMdRx7tYJFJ1ueOkv8VbW
license:                MIT
maintainer:             Michael Snoyman <michael@snoyman.com>
author:                 Michael Snoyman <michael@snoyman.com>
stability:              Stable
homepage:               http://www.yesodweb.com/book/persistent
synopsis:               Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:               Database, Yesod
abi:                    5103e9eae679273703131b46df7ee5b1
exposed:                True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:            /usr/lib/ghc-9.6.6/site-local/persistent-sqlite-2.13.2.0
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/persistent-sqlite-2.13.2.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/persistent-sqlite-2.13.2.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-persistent-sqlite
hs-libraries:           HSpersistent-sqlite-2.13.2.0-4aMdRx7tYJFJ1ueOkv8VbW
extra-libraries:        pthread sqlite3
extra-libraries-static: sqlite3 m z
include-dirs:           /usr/include
depends:
    aeson-2.2.2.0-4XfhhWkmpwnB2gRUwfJP7g base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-J8ndGOkTyJX5j6RwH3LErP
    containers-0.6.7 microlens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT
    monad-logger-0.3.42-I2HlTneEqI9INUdPRMTifZ mtl-2.3.1
    persistent-2.14.6.0-JAjb2qYOThL5Wvc8hdouPf
    resource-pool-0.2.3.2-A0BZLiVdnza6cMxj0HAtgc
    resourcet-1.3.0-BrdZatkp6QIII6Vs5RqUd1 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-3DXXOqLpcMZGFktSBwG2cs

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:           /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

